==> jc-1.4.0.tar.gz: java/lang/ThreadLocal.h <==
// public class java.lang.ThreadLocal

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb9becf335f12a20 java_lang_ThreadLocal

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_ThreadLocal_H_
#define _JC_java_lang_ThreadLocal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_lang_ThreadLocal$sub_refs	_jc_java_lang_ThreadLocal$sub_refs;
typedef struct _jc_java_lang_ThreadLocal$sub_nonrefs	_jc_java_lang_ThreadLocal$sub_nonrefs;
typedef struct _jc_java_lang_ThreadLocal$refs	_jc_java_lang_ThreadLocal$refs;
typedef struct _jc_java_lang_ThreadLocal$nonrefs	_jc_java_lang_ThreadLocal$nonrefs;
typedef struct _jc_java_lang_ThreadLocal$object	_jc_java_lang_ThreadLocal$object;

typedef struct _jc_java_lang_ThreadLocal$fields_struct	_jc_java_lang_ThreadLocal$fields_struct;
typedef const struct _jc_java_lang_ThreadLocal$vmethods	_jc_java_lang_ThreadLocal$vmethods;
typedef const struct _jc_java_lang_ThreadLocal$vtable	_jc_java_lang_ThreadLocal$vtable;
typedef const struct _jc_java_lang_ThreadLocal$vtype	_jc_java_lang_ThreadLocal$vtype;

// Class fields structure
struct _jc_java_lang_ThreadLocal$fields_struct {
	struct _jc_java_lang_Object$object	*NULL;
};
extern _jc_java_lang_ThreadLocal$fields_struct _jc_java_lang_ThreadLocal$class_fields;

// Constructors
extern void _jc_java_lang_ThreadLocal$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_ThreadLocal$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);
extern struct _jc_java_lang_Object$object *_jc_java_lang_ThreadLocal$method$initialValue$2952eeaa89b47d4b(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);
extern void _jc_java_lang_ThreadLocal$method$set$5d552207ec221301(_jc_env *, struct _jc_java_lang_ThreadLocal$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_ThreadLocal$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ThreadLocal$method_info$get$a27f05608bfbd09b;
extern _jc_method _jc_java_lang_ThreadLocal$method_info$initialValue$2952eeaa89b47d4b;
extern _jc_method _jc_java_lang_ThreadLocal$method_info$set$5d552207ec221301;
extern _jc_method _jc_java_lang_ThreadLocal$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_lang_ThreadLocal$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_lang_ThreadLocal$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);
	struct _jc_java_lang_Object$object	*(*initialValue$2952eeaa89b47d4b)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);
	void	(*set$5d552207ec221301)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *, struct _jc_java_lang_Object$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *);
};

// Vtable
struct _jc_java_lang_ThreadLocal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ThreadLocal$vmethods	java_lang_ThreadLocal;
};

// Vtype
struct _jc_java_lang_ThreadLocal$vtype {
	_jc_type			type;
	_jc_java_lang_ThreadLocal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ThreadLocal$sub_refs {
	struct _jc_java_lang_Object$object	*value;
	struct _jc_object	*valueMap;
};

// Reference instance fields (object)
struct _jc_java_lang_ThreadLocal$refs {
    _jc_java_lang_ThreadLocal$sub_refs	java_lang_ThreadLocal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ThreadLocal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ThreadLocal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ThreadLocal$sub_nonrefs	java_lang_ThreadLocal;
};

// Object instance structure
struct _jc_java_lang_ThreadLocal$object {
	_jc_java_lang_ThreadLocal$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ThreadLocal$vtype	*vtype;
	_jc_java_lang_ThreadLocal$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ThreadLocal$vtype _jc_java_lang_ThreadLocal$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ThreadLocal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ThreadLocal$class_object;

#endif	/* _JC_java_lang_ThreadLocal_H_ */

==> jc-1.4.6.tar.gz: java/lang/ThreadLocal.h <==
// public class java.lang.ThreadLocal

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a0bc393bff0eefc java_lang_ThreadLocal

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_ThreadLocal_H_
#define _JC_java_lang_ThreadLocal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ThreadLocal__24Key$object;

// Typedefs
typedef struct _jc_java_lang_ThreadLocal$sub_refs	_jc_java_lang_ThreadLocal$sub_refs;
typedef struct _jc_java_lang_ThreadLocal$sub_nonrefs	_jc_java_lang_ThreadLocal$sub_nonrefs;
typedef struct _jc_java_lang_ThreadLocal$refs	_jc_java_lang_ThreadLocal$refs;
typedef struct _jc_java_lang_ThreadLocal$nonrefs	_jc_java_lang_ThreadLocal$nonrefs;
typedef struct _jc_java_lang_ThreadLocal$object	_jc_java_lang_ThreadLocal$object;

typedef struct _jc_java_lang_ThreadLocal$fields_struct	_jc_java_lang_ThreadLocal$fields_struct;
typedef const struct _jc_java_lang_ThreadLocal$vmethods	_jc_java_lang_ThreadLocal$vmethods;
typedef const struct _jc_java_lang_ThreadLocal$vtable	_jc_java_lang_ThreadLocal$vtable;
typedef const struct _jc_java_lang_ThreadLocal$vtype	_jc_java_lang_ThreadLocal$vtype;

// Class fields structure
struct _jc_java_lang_ThreadLocal$fields_struct {
	struct _jc_java_lang_Object$object	*NULL;
};
extern _jc_java_lang_ThreadLocal$fields_struct _jc_java_lang_ThreadLocal$class_fields;

// Constructors
extern void _jc_java_lang_ThreadLocal$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_ThreadLocal$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_lang_ThreadLocal$method$initialValue$2952eeaa89b47d4b(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ThreadLocal$method$set$5d552207ec221301(_jc_env *, struct _jc_java_lang_ThreadLocal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ThreadLocal$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ThreadLocal$method_info$get$a27f05608bfbd09b;
extern _jc_method _jc_java_lang_ThreadLocal$method_info$initialValue$2952eeaa89b47d4b;
extern _jc_method _jc_java_lang_ThreadLocal$method_info$set$5d552207ec221301;
extern _jc_method _jc_java_lang_ThreadLocal$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_lang_ThreadLocal$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ThreadLocal$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*initialValue$2952eeaa89b47d4b)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;
	void	(*set$5d552207ec221301)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_ThreadLocal$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ThreadLocal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ThreadLocal$vmethods	java_lang_ThreadLocal;
};

// Vtype
struct _jc_java_lang_ThreadLocal$vtype {
	_jc_type			type;
	_jc_java_lang_ThreadLocal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ThreadLocal$sub_refs {
	struct _jc_java_lang_ThreadLocal__24Key$object	*key;
};

// Reference instance fields (object)
struct _jc_java_lang_ThreadLocal$refs {
    _jc_java_lang_ThreadLocal$sub_refs	java_lang_ThreadLocal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ThreadLocal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ThreadLocal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ThreadLocal$sub_nonrefs	java_lang_ThreadLocal;
};

// Object instance structure
struct _jc_java_lang_ThreadLocal$object {
	_jc_java_lang_ThreadLocal$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ThreadLocal$vtype	*vtype;
	_jc_java_lang_ThreadLocal$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ThreadLocal$vtype _jc_java_lang_ThreadLocal$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ThreadLocal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ThreadLocal$class_object;

#endif	/* _JC_java_lang_ThreadLocal_H_ */
